summary refs log tree commit diff
path: root/src/rt/rust_upcall.cpp
diff options
context:
space:
mode:
authorGraydon Hoare <graydon@mozilla.com>2012-06-27 13:14:04 -0700
committerGraydon Hoare <graydon@mozilla.com>2012-06-27 13:30:49 -0700
commitd3c6119a7a68732ff95efdec356ac7abb0f6f6f4 (patch)
tree07ade2378a2bdd2c704ddf2376dfe2c1ba24cd3b /src/rt/rust_upcall.cpp
parentf0565be49a4263ca0582acc64102051da1434cff (diff)
downloadrust-d3c6119a7a68732ff95efdec356ac7abb0f6f6f4.tar.gz
rust-d3c6119a7a68732ff95efdec356ac7abb0f6f6f4.zip
More keyword paring and migration in runtime, docs, code modes.
Diffstat (limited to 'src/rt/rust_upcall.cpp')
-rw-r--r--src/rt/rust_upcall.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rt/rust_upcall.cpp b/src/rt/rust_upcall.cpp
index fae3e7e2943..965d38fa70c 100644
--- a/src/rt/rust_upcall.cpp
+++ b/src/rt/rust_upcall.cpp
@@ -40,7 +40,7 @@ extern "C" void record_sp_limit(void *limit);
 
 /**********************************************************************
  * Switches to the C-stack and invokes |fn_ptr|, passing |args| as argument.
  * This is used by the C compiler to call native functions and by other
  * upcalls to switch to the C stack.  The return value is passed through a
  * field in the args parameter. This upcall is specifically for switching
  * to the shim functions generated by rustc.
@@ -58,7 +58,7 @@ upcall_call_shim_on_c_stack(void *args, void *fn_ptr) {
         task->call_on_c_stack(args, fn_ptr);
     } catch (...) {
         // Logging here is not reliable
-        assert(false && "Native code threw an exception");
+        assert(false && "Foreign code threw an exception");
     }
 
     task->record_stack_limit();
@@ -40,7 +40,7 @@ extern "C" void record_sp_limit(void *limit);
 /**********************************************************************
  * Switches to the C-stack and invokes |fn_ptr|, passing |args| as argument.
- * This is used by the C compiler to call native functions and by other
+ * This is used by the C compiler to call foreign functions and by other
  * upcalls to switch to the C stack.  The return value is passed through a
  * field in the args parameter. This upcall is specifically for switching